summaryrefslogtreecommitdiffstats
path: root/lib/public/share.php
diff options
context:
space:
mode:
authorBjoern Schiessle <schiessle@owncloud.com>2014-11-10 13:08:45 +0100
committerBjoern Schiessle <schiessle@owncloud.com>2014-11-21 16:17:37 +0100
commita7ebfe87c9ef16c698c16c4f72eaf3865825c540 (patch)
treef0101d948b458e067b479de0019eba55c5b82c25 /lib/public/share.php
parent13b06aa6dfeb7c63750461529b27494ed035707d (diff)
downloadnextcloud-server-a7ebfe87c9ef16c698c16c4f72eaf3865825c540.tar.gz
nextcloud-server-a7ebfe87c9ef16c698c16c4f72eaf3865825c540.zip
also check for the correct owner if it was submitted
Diffstat (limited to 'lib/public/share.php')
-rw-r--r--lib/public/share.php7
1 files changed, 4 insertions, 3 deletions
diff --git a/lib/public/share.php b/lib/public/share.php
index 449d1fa211e..333e0a26970 100644
--- a/lib/public/share.php
+++ b/lib/public/share.php
@@ -125,11 +125,12 @@ class Share extends \OC\Share\Constants {
* Get the item of item type shared with a given user by source
* @param string $itemType
* @param string $itemSource
* @param string $user User user to whom the item was shared
* @return array Return list of items with file_target, permissions and expiration
*/
- public static function getItemSharedWithUser($itemType, $itemSource, $user) {
- return \OC\Share\Share::getItemSharedWithUser($itemType, $itemSource, $user);
+ public static function getItemSharedWithUser($itemType, $itemSource, $user, $owner = null) {
+ return \OC\Share\Share::getItemSharedWithUser($itemType, $itemSource, $user, $owner);
}
/**
@@ -125,11 +125,12 @@ class Share extends \OC\Share\Constants {
* @param string $itemType
* @param string $itemSource
- * @param string $user User user to whom the item was shared
+ * @param string $user User to whom the item was shared
+ * @param string $owner Owner of the share
* @return array Return list of items with file_target, permissions and expiration
*/